@@ -1,14 +1,10 @@
 """Data model for a Z-Wave JS controller."""
-from typing import List
+from __future__ import annotations
+
+from typing import TypedDict
 
-from ...const import TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED
 from .statistics import ControllerStatisticsDataType
 
-if TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED:
-    from typing_extensions import TypedDict
-else:
-    from typing import TypedDict
-
 
 class ControllerDataType(TypedDict, total=False):
     """Represent a controller data dict type."""
@@ -27,9 +23,11 @@ class ControllerDataType(TypedDict, total=False):
     manufacturerId: int
     productType: int
     productId: int
-    supportedFunctionTypes: List[int]
+    supportedFunctionTypes: list[int]
     sucNodeId: int
     supportsTimers: bool
     isHealNetworkActive: bool
     statistics: ControllerStatisticsDataType
     inclusionState: int
+    rfRegion: int
+    status: int
